/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package an;

import org.opengion.fukurou.business.BizLogic_TABLE;
import org.opengion.fukurou.util.StringUtil;

/**
 * アンケート項目登録  (AN0003) の 業務ロジックです。
 * 
 * ここでは、アンケート項目マスタ(AN02)の追加・変更・削除を行っています。
 *
 * @og.rev 2010/06/18 新規作成
 * 
 * @version 5.0
 * @author Hiroki Nakamura
 * @since JDK1.6,
 */
public class AN0003A extends BizLogic_TABLE {

	/**
	 * メインカーソルの各行(変更区分="A")で呼ばれるチェックロジックを定義します。
	 * ここでは何も実装されていません。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean inschk( final int row ) {
		return true;
	}

	/**
	 * メインカーソルの各行(変更区分="C")で呼ばれるチェックロジックを定義します。
	 * ここでは何も実装されていません。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean modchk( final int row ) {
		return true;
	}

	/**
	 * メインカーソルの各行(変更区分="D")で呼ばれるチェックロジックを定義します。
	 * ここでは何も実装されていません。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean delchk( final int row ) {
		return true;
	}

	/**
	 * メインカーソルの各行(変更区分の各処理の前)で呼ばれるチェックロジックを定義します。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean befchk( final int row ) {
		// 分類をキーに、桁数を求めます。
		set( "KLENGTH", StringUtil.valueOf( Utils.getLength( line( "KBUNRUI" ), linei( "KLENGTH" ) ) ) );
		return true;
	}

	/**
	 * メインカーソルの各行(変更区分="A")で呼ばれるロジックを定義します。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean insert( final int row ) {
		// 0.1 Oracle、MySQL、HSQLDB対応
//		sql( "select nextval('AN02S01') PGSEQ" );
//		set( "CDSITSU", "S" + StringUtil.intFill( var( "PGSEQ" ), 9 ) );
		String seq = StringUtil.valueOf( seq( "AN02S01" ) );
		set( "CDSITSU", "S" + StringUtil.intFill( seq, 9 ) );

		String sql = "insert into AN02("
			+ "USERID,CDANK,CDSITSU,SEQNO,NAIYO,SITSUGRP,IMGNAI,FGKEY,FGMUST,KBUNRUI,KLENGTH,KNOTE,SUONELINE,RSCODE,INIVAL,CSKEY,CSWAY,SUCS,VDCDTN"
			+ ",BIKO,FGJ,DYSET,PGSET,PGPSET,USRSET,DYUPD,PGUPD,PGPUPD,USRUPD"
			+ ") values ("
			+ "'{@CON.USERID}','{@CDANK}','{@CDSITSU}',[SEQNO],[NAIYO],[SITSUGRP],[IMGNAI],[FGKEY],[FGMUST],[KBUNRUI],{@KLENGTH},[KNOTE],[SUONELINE],[RSCODE],[INIVAL],[CSKEY],[CSWAY],[SUCS],[VDCDTN]"
			+ ",'','1','{@CON.YMDH}','{@CON.PGID}','{@CON.PGPID}','{@CON.USERID}','{@CON.YMDH}','{@CON.PGID}','{@CON.PGPID}','{@CON.USERID}'"
			+ ")";
		sql( sql );

		// カラムリソースを登録します。
		boolean rtn = call( "an.ColumnRes", "CDANK,CDSITSU,NAIYO,KBUNRUI,KLENGTH,CDKH", "{@CDANK},{@CDSITSU},[NAIYO],[KBUNRUI],{@KLENGTH},A" );
		if( !rtn ) { return false; }

		return true;
	}

	/**
	 * メインカーソルの各行(変更区分="C")で呼ばれるロジックを定義します。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean modify( final int row ) {
		String sql = "update AN02 set"
			+ " SEQNO = [SEQNO]"
			+ ",NAIYO = [NAIYO]"
			+ ",SITSUGRP = [SITSUGRP]"
			+ ",IMGNAI = [IMGNAI]"
			+ ",FGKEY = [FGKEY]"
			+ ",FGMUST = [FGMUST]"
			+ ",KBUNRUI = [KBUNRUI]"
			+ ",KLENGTH = {@KLENGTH}"
			+ ",KNOTE = [KNOTE]"
			+ ",SUONELINE = [SUONELINE]"
			+ ",RSCODE = [RSCODE]"
			+ ",INIVAL = [INIVAL]"
			+ ",CSKEY = [CSKEY]"
			+ ",CSWAY = [CSWAY]"
			+ ",SUCS = [SUCS]"
			+ ",VDCDTN = [VDCDTN]"
			+ ",DYUPD = '{@CON.YMDH}'"
			+ ",PGUPD = '{@CON.PGID}'"
			+ ",PGPUPD = '{@CON.PGPID}'"
			+ ",USRUPD = '{@CON.USERID}'"
			+ "where UNIQ = [UNIQ]";
		sql( sql );

		// カラムリソースを登録します。
		boolean rtn = call( "an.ColumnRes", "CDANK,CDSITSU,NAIYO,KBUNRUI,KLENGTH,CDKH", "{@CDANK},[CDSITSU],[NAIYO],[KBUNRUI],{@KLENGTH},A" );
		if( !rtn ) { return false; }

		return true;
	}

	/**
	 * メインカーソルの各行(変更区分="D")で呼ばれるロジックを定義します。
	 * 
	 * @param row 行番号
	 * @return 処理が正常終了したか
	 */
	@Override
	protected boolean delete( final int row ) {
		String sql = "update AN02 set"
			+ " FGJ = '9'"
			+ ",DYUPD = '{@CON.YMDH}'"
			+ ",PGUPD = '{@CON.PGID}'"
			+ ",PGPUPD = '{@CON.PGPID}'"
			+ ",USRUPD = '{@CON.USERID}'"
			+ "where UNIQ = [UNIQ]";
		sql( sql );

		// カラムリソースを削除します。
		boolean rtn = call( "an.ColumnRes", "CDANK,CDSITSU,NAIYO,KBUNRUI,KLENGTH,CDKH", "{@CDANK},[CDSITSU],[NAIYO],{@KLENGTH},[KLENGTH],D" );
		if( !rtn ) { return false; }

		return true;
	}
}

